@@ -301,7 +301,9 @@ class ParsedUrl:
         except Exception:  # not raised in python2.7+, just returns None
             # old style rsync://host::[/]dest, are still valid, though they contain no port
             if not (self.scheme in ['rsync'] and re.search('::[^:]*$', self.url_string)):
-                raise InvalidBackendURL("Syntax error (port) in: %s A%s B%s C%s" % (url_string, (self.scheme in ['rsync']), re.search('::[^:]+$', self.netloc), self.netloc))
+                raise InvalidBackendURL("Syntax error (port) in: %s A%s B%s C%s" %
+                                        (url_string, (self.scheme in ['rsync']),
+                                         re.search('::[^:]+$', self.netloc), self.netloc))
 
         # Our URL system uses two slashes more than urlparse's does when using
         # non-netloc URLs.  And we want to make sure that if urlparse assuming
@@ -393,9 +395,9 @@ def retry(operation, fatal=True):
                                  % (n, e.__class__.__name__, util.uexc(e)))
                     if not at_end:
                         if isinstance(e, TemporaryLoadException):
-                            time.sleep(90)  # wait longer before trying again
+                            time.sleep(3 * globals.backend_retry_delay)  # wait longer before trying again
                         else:
-                            time.sleep(30)  # wait a bit before trying again
+                            time.sleep(globals.backend_retry_delay)  # wait a bit before trying again
                         if hasattr(self.backend, '_retry_cleanup'):
                             self.backend._retry_cleanup()
 
